@@ -74,6 +74,7 @@ my %hierarchy = (
     'Portion' => 'ResourceBase',
     'Portions' => 'ResourceBase',
     'PptxExportOptions' => 'ExportOptions',
+    'ProtectionProperties' => 'ResourceBase',
     'RemoveShape' => 'Task',
     'RemoveSlide' => 'Task',
     'ReorderSlide' => 'Task',
@@ -94,6 +95,7 @@ my %hierarchy = (
     'SlideAnimation' => 'ResourceBase',
     'SlideBackground' => 'ResourceBase',
     'SlideComments' => 'ResourceBase',
+    'SlideProperties' => 'ResourceBase',
     'Slides' => 'ResourceBase',
     'SolidFill' => 'FillFormat',
     'SplitDocumentResult' => 'ResourceBase',
@@ -238,6 +240,7 @@ my %determiners = (
     'Portion' => {  },
     'Portions' => {  },
     'PptxExportOptions' => { 'Format' => 'pptx', },
+    'ProtectionProperties' => {  },
     'RemoveShape' => { 'Type' => 'RemoveShape', },
     'RemoveSlide' => { 'Type' => 'RemoveSlide', },
     'ReorderSlide' => { 'Type' => 'ReoderSlide', },
@@ -258,6 +261,7 @@ my %determiners = (
     'SlideAnimation' => {  },
     'SlideBackground' => {  },
     'SlideComments' => {  },
+    'SlideProperties' => {  },
     'Slides' => {  },
     'SolidFill' => { 'Type' => 'Solid', },
     'SplitDocumentResult' => {  },
